@@ -13,7 +13,9 @@ __all__ = [
     "Exception",
     "IllegalArgumentException",
     "NullPointerException",
+    "Number",
     "Object",
+    "Runnable",
     "RuntimeException",
     "StackTraceElement",
     "String",
@@ -26,7 +28,7 @@ __all__ = [
 import __builtin__ as builtins
 import time
 
-from typing import Any, Optional, TypeVar, Union
+from typing import Any, List, Optional, TypeVar, Union
 
 String = Union[str, unicode]
 T = TypeVar("T")
@@ -39,6 +41,22 @@ class Object(object):
     methods of this class.
     """
 
+    def __cmp__(self, other):
+        # type: (Object) -> bool
+        pass
+
+    def __ge__(self, other):
+        # type: (Object) -> bool
+        pass
+
+    def __gt__(self, other):
+        # type: (Object) -> bool
+        pass
+
+    def __lt__(self, other):
+        # type: (Object) -> bool
+        pass
+
     def equals(self, obj):
         # type: (Object) -> bool
         pass
@@ -109,6 +127,12 @@ class CharSequence(object):
         raise NotImplementedError
 
 
+class Runnable(object):
+    def run(self):
+        # type: () -> None
+        raise NotImplementedError
+
+
 class Class(Object):
     def asSubClass(self, clazz):
         # type: (Class) -> U
@@ -121,23 +145,56 @@ class Class(Object):
 
 class Enum(Object):
     def compareTo(self, o):
+        # type: (Enum) -> int
         pass
 
     def getDeclaringClass(self):
+        # type: () -> Class
         pass
 
     def name(self):
+        # type: () -> String
         pass
 
     def ordinal(self):
+        # type: () -> int
         pass
 
-    def valueOf(self, enumType, name):
+    @staticmethod
+    def valueOf(enumType, name):
+        # type: (Class, String) -> Enum
+        pass
+
+
+class Number(Object):
+    def byteValue(self):
+        # type: () -> int
+        pass
+
+    def doubleValue(self):
+        # type: () -> float
+        raise NotImplementedError
+
+    def floatValue(self):
+        # type: () -> float
+        raise NotImplementedError
+
+    def intValue(self):
+        # type: () -> int
+        raise NotImplementedError
+
+    def longValue(self):
+        # type: () -> long
+        raise NotImplementedError
+
+    def shortValue(self):
+        # type: () -> int
         pass
 
 
 class StackTraceElement(Object):
     def __init__(self, *args):
+        # type: (Any) -> None
         pass
 
     def getClassLoaderName(self):
@@ -179,6 +236,7 @@ class StringBuffer(Object, CharSequence):
         pass
 
     def append(self, *args):
+        # type: (Any) -> StringBuffer
         pass
 
     def appendCodePoint(self, codePoint):
@@ -230,6 +288,7 @@ class StringBuffer(Object, CharSequence):
         pass
 
     def insert(self, *args):
+        # type: (Any) -> StringBuffer
         pass
 
     def lastIndexOf(self, string, fromIndex=0):
@@ -408,9 +467,11 @@ class Throwable(Object, builtins.Exception):
         pass
 
     def getStackTrace(self):
+        # type: () -> List[StackTraceElement]
         pass
 
     def getSuppressed(self):
+        # type: () -> List[Throwable]
         pass
 
     def initCause(self, cause=None):
@@ -423,9 +484,11 @@ class Throwable(Object, builtins.Exception):
         return "message"
 
     def printStackTrace(self, *args):
+        # type: (Any) -> None
         pass
 
     def setStackTrace(self, stackTrace):
+        # type: (List[StackTraceElement]) -> None
         pass
 
     def toString(self):
