@@ -14,50 +14,138 @@ __all__ = [
     "JTextField",
 ]
 
-from typing import Any, List, Optional, Union
+from typing import Any, List, Optional
 
-from java.awt import Container, Frame
+from java.awt import Component, Container, Frame, Graphics
 from java.lang import String
+from java.util import Locale
+from javax.swing.event import AncestorListener
+from javax.swing.plaf import DesktopPaneUI
 from javax.swing.text import JTextComponent
 
 
+class DesktopManager(object):
+    def activateFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def beginDragginFrame(self, f):
+        # type: (JComponent) -> None
+        raise NotImplementedError
+
+    def beginResizingFrame(self, f, direction):
+        # type: (JComponent, int) -> None
+        raise NotImplementedError
+
+    def closeFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def deactivateFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def deiconifyFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def dragFrame(self, f, newX, newY):
+        # type: (JComponent, int, int) -> None
+        raise NotImplementedError
+
+    def endDraggingFrame(self, f):
+        # type: (JComponent) -> None
+        raise NotImplementedError
+
+    def endResizing(self, f):
+        # type: (JComponent) -> None
+        raise NotImplementedError
+
+    def iconifyFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def maximizeFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def minimizeFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def openFrame(self, f):
+        # type: (JInternalFrame) -> None
+        raise NotImplementedError
+
+    def resizeFrame(self, f, newX, newY, newWidth, newHeight):
+        # type: (JComponent, int, int, int, int) -> None
+        raise NotImplementedError
+
+    def setBoundsForFrame(self, f, newX, newY, newWidth, newHeight):
+        # type: (JComponent, int, int, int, int) -> None
+        raise NotImplementedError
+
+
 class Icon(object):
     def getIconHeight(self):
+        # type: () -> int
         raise NotImplementedError
 
     def getIconWidth(self):
+        # type: () -> int
         raise NotImplementedError
 
     def paintIcon(self, c, g, x, y):
+        # type: (Component, Graphics, int, int) -> None
         raise NotImplementedError
 
 
 class JComponent(Container):
-    """The base class for all Swing components except top-level
-    containers.
-    """
+    TOOL_TIP_TEXT_KEY = None  # type: String
+    UNDEFINED_CONDITION = None  # type: int
+    WHEN_ANCESTOR_OF_FOCUSED_COMPONENT = None  # type: int
+    WHEN_FOCUSED = None  # type: int
+    WHEN_IN_FOCUSED_WINDOW = None  # type: int
 
     def __init__(self):
         # type: () -> None
         pass
 
+    def addAncestorListener(self, listener):
+        # type: (AncestorListener) -> None
+        pass
 
-class JFrame(Frame):
-    """An extended version of java.awt.Frame that adds support for the
-    JFC/Swing component architecture.
-    """
+    def addNotify(self):
+        # type: () -> None
+        pass
 
-    def __init__(self, *args):
-        # type: (Any) -> None
+    def createToolTip(self):
+        # type: () -> JToolTip
+        pass
+
+    @staticmethod
+    def getDefaultLocale():
+        # type: () -> Locale
+        pass
+
+    @staticmethod
+    def isLightweightComponent(c):
+        # type: (Component) -> bool
+        pass
+
+    @staticmethod
+    def setDefaultLocale(l):
+        # type: (Locale) -> None
         pass
 
 
-class JInternalFrame(JComponent):
-    """A lightweight object that provides many of the features of a
-    native frame, including dragging, closing, becoming an icon,
-    resizing, title display, and support for a menu bar.
-    """
+class JFrame(Frame):
+    def __init__(self, *args):
+        # type: (Any) -> None
+        super(JFrame, self).__init__(*args)
 
+
+class JInternalFrame(JComponent):
     def __init__(
         self,
         title=None,  # type: Optional[String]
@@ -94,48 +182,64 @@ class JLayeredPane(JComponent):
         super(JLayeredPane, self).__init__()
 
     def getComponentCountInLayer(self, layer):
+        # type: (int) -> int
         pass
 
     def getLayer(self, c):
+        # type: (Component) -> int
         pass
 
     def highestLayer(self):
+        # type: () -> int
         pass
 
     def lowestLayer(self):
+        # type: () -> int
         pass
 
     def setPosition(self, c, position):
+        # type: (Component, int) -> None
         pass
 
 
 class JDesktopPane(JLayeredPane):
+    LIVE_DRAG_MODE = None  # type: int
+    OUTLINE_DRAG_MODE = None  # type: int
+
     def __init__(self):
         # type: () -> None
         super(JDesktopPane, self).__init__()
 
     def getAllFrames(self):
+        # type: () -> List[JInternalFrame]
         pass
 
-    def getAllFramesInLayer(self):
+    def getAllFramesInLayer(self, layer):
+        # type: (int) -> List[JInternalFrame]
         pass
 
     def getDesktopManager(self):
+        # type: () -> DesktopManager
         pass
 
     def getDragMode(self):
+        # type: () -> int
         pass
 
     def getSelectedFrame(self):
+        # type: () -> JInternalFrame
         pass
 
     def getUI(self):
+        # type: () -> DesktopPaneUI
         pass
 
     def getUIClassID(self):
+        # type: () -> String
         pass
 
     def updateUI(self):
+        # type: () -> None
         pass
 
 
@@ -246,14 +350,16 @@ class JPanel(JComponent):
 
 
 class JToolTip(JComponent):
-    def getAccessibleContext(self):
-        pass
+    def __init__(self):
+        # type: () -> None
+        super(JToolTip, self).__init__()
 
     def getComponent(self):
-        print(self)
-        return JComponent()
+        # type: () -> JComponent
+        pass
 
     def getTipText(self):
+        # type: () -> String
         pass
 
 
@@ -272,28 +378,6 @@ class JPopupMenu(JComponent):
         super(JPopupMenu, self).__init__()
         print(label)
 
-    def addAncestorListener(self, listener):
-        pass
-
-    def addNotify(self):
-        pass
-
-    def createToolTip(self):
-        print(self)
-        return JToolTip()
-
-    @staticmethod
-    def getDefaultLocale():
-        pass
-
-    @staticmethod
-    def isLightweightComponent(c):
-        pass
-
-    @staticmethod
-    def setDefaultLocale(l):
-        pass
-
 
 class JTextField(JTextComponent):
     """JTextField is a lightweight component that allows the editing of
