@@ -13,6 +13,7 @@ __all__ = [
     "PyDescriptor",
     "PyException",
     "PyFrame",
+    "PyFunction",
     "PyMethodDescr",
     "PyNewWrapper",
     "PyObject",
@@ -24,7 +25,7 @@ __all__ = [
 ]
 
 from enum import Enum
-from typing import Any, Iterable, List, Optional, Tuple, Union
+from typing import Any, Iterable, Iterator, List, Optional, Tuple, Union
 
 from java.io import PrintWriter
 from java.lang import Class, Object, RuntimeException, String, StringBuilder, Throwable
@@ -58,10 +59,6 @@ class PyObject(Object):
         # type: (Any, Any) -> PyObject
         pass
 
-    def __cmp__(self, other):
-        # type: (PyObject) -> int
-        pass
-
     def __coerce__(self, pyo):
         # type: (PyObject) -> PyObject
         pass
@@ -122,10 +119,6 @@ class PyObject(Object):
         # type: (PyObject) -> PyObject
         pass
 
-    def __ge__(self, other):
-        # type: (PyObject) -> PyObject
-        pass
-
     def __get__(self, obj, type):
         # type: (PyObject, PyObject) -> PyObject
         pass
@@ -146,10 +139,6 @@ class PyObject(Object):
         # type: (PyObject, PyObject, Optional[PyObject]) -> None
         pass
 
-    def __gt__(self, other):
-        # type: (PyObject) -> PyObject
-        pass
-
     def __hex__(self):
         # type: () -> str
         pass
@@ -215,7 +204,7 @@ class PyObject(Object):
         pass
 
     def __iter__(self):
-        # type: () -> Iterable[PyObject]
+        # type: () -> Iterator[PyObject]
         pass
 
     def __iternext__(self):
@@ -241,10 +230,6 @@ class PyObject(Object):
         # type: (PyObject) -> PyObject
         pass
 
-    def __lt__(self, other):
-        # type: (PyObject) -> PyObject
-        pass
-
     def __mod__(self, other):
         # type: (PyObject) -> PyObject
         pass
@@ -1071,6 +1056,12 @@ class PyFrame(PyObject):
         pass
 
 
+class PyFunction(PyObject):
+    def __init__(self, *args):
+        print(args)
+        super(PyFunction, self).__init__()
+
+
 class PyMethodDescr(PyDescriptor):
     def __init__(self, t, func):
         super(PyMethodDescr, self).__init__(t, func)
